/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.adapters;

import org.wamblee.system.core.AbstractComponent;
import org.wamblee.system.core.ProvidedInterface;
import org.wamblee.system.core.RequiredInterface;
import org.wamblee.system.core.Scope;

/**
 * A Class Adapter adapts a given class to a Component.
 * 
 * @author Erik Brakkee
 */
public class ClassAdapter extends AbstractComponent<Object> {
    private ClassConfiguration classConfig;

    /**
     * Creates a new ClassAdapter object.
     * 
     */
    public ClassAdapter(String aName, ClassConfiguration aClassConfig) {
        super(aName, aClassConfig.getProvidedInterfaces().toArray(
            new ProvidedInterface[0]), aClassConfig.getRequiredInterfaces()
            .toArray(new RequiredInterface[0]));
        classConfig = aClassConfig;
    }

    @Override
    protected Object doStart(Scope aScope) {
        Object obj = classConfig.create(aScope);
        classConfig.inject(aScope, obj);

        for (ProvidedInterface provided : getProvidedInterfaces()) {
            addInterface(provided, obj, aScope);
        }

        return obj;
    }

    @Override
    protected void doStop(Object aRuntime) {
        // Empty.
    }
}
