/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */ 
package org.wamblee.system.components;

public class ORMappingConfig {

    public enum DatabaseType {
        MYSQL_INNO_DB, DERBY;

        public static interface Switch<T> {
            T handleMySqlInnoDb();

            T handleDerby();
        }

        public <T> T handleCases(Switch<T> aSwitch) {

            switch (this) {
            case MYSQL_INNO_DB: {
                return aSwitch.handleMySqlInnoDb();
            }
            case DERBY: {
                return aSwitch.handleDerby();
            }
            default: {
                throw new RuntimeException("Unhandled case " + this);
            }
            }
        }
    };

    private boolean schemaUpdate;
    private DatabaseType type;

    public ORMappingConfig(boolean aSchemaUpdate, DatabaseType aType) {
        schemaUpdate = aSchemaUpdate;
        type = aType;
    }

    public boolean isSchemaUpdate() {
        return schemaUpdate;
    }

    public DatabaseType getType() {
        return type;
    }

}
